@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ################################################################################
-#  Copyright (C) 2012  Travis Shirk <travis@pobox.com>
+#  Copyright (C) 2012-2015  Travis Shirk <travis@pobox.com>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@ from . import LOCAL_FS_ENCODING
 from .utils import guessMimetype
 from . import compat
 
-import logging
-log = logging.getLogger(__name__)
+from .utils.log import getLogger
+log = getLogger(__name__)
 
 
 AUDIO_NONE = 0
