@@ -34,8 +34,8 @@ from . import frames
 from .headers import TagHeader, ExtendedTagHeader
 from ..compat import StringTypes, BytesType, unicode, UnicodeType
 
-import logging
-log = logging.getLogger(__name__)
+from ..utils.log import getLogger
+log = getLogger(__name__)
 
 
 class TagException(Error):
@@ -225,7 +225,8 @@ class Tag(core.Tag):
     @requireUnicode(2)
     def setTextFrame(self, fid, txt):
         if not fid.startswith("T") or fid.startswith("TX"):
-            raise ValueError("Invalid frame-id for text frame")
+            raise ValueError("Invalid frame-id for text frame: " +
+                             unicode(fid, "ascii"))
 
         if not txt and self.frame_set[fid]:
             del self.frame_set[fid]
@@ -234,7 +235,8 @@ class Tag(core.Tag):
 
     def getTextFrame(self, fid):
         if not fid.startswith("T") or fid.startswith("TX"):
-            raise ValueError("Invalid frame-id for text frame")
+            raise ValueError("Invalid frame-id for text frame: " +
+                             unicode(fid, "ascii"))
         f = self.frame_set[fid]
         return f[0].text if f else None
 
@@ -788,15 +790,18 @@ class Tag(core.Tag):
             assert(type(s) is str)
             return s.ljust(n, '\x00')[:n]
 
+        def encode(s):
+            return s.encode("latin_1", "replace")
+
         # Build tag buffer.
         tag = b"TAG"
-        tag += pack(self.title.encode("latin_1") if self.title else b"", 30)
-        tag += pack(self.artist.encode("latin_1") if self.artist else b"", 30)
-        tag += pack(self.album.encode("latin_1") if self.album else b"", 30)
+        tag += pack(encode(self.title) if self.title else b"", 30)
+        tag += pack(encode(self.artist) if self.artist else b"", 30)
+        tag += pack(encode(self.album) if self.album else b"", 30)
 
         release_date = self.getBestDate()
         year = str(release_date.year) if release_date else b""
-        tag += pack(year.encode("latin_1"), 4)
+        tag += pack(encode(year), 4)
 
         cmt = ""
         for c in self.comments:
@@ -807,7 +812,7 @@ class Tag(core.Tag):
             elif c.description == "":
                 cmt = c.text
                 # Keep searching in case we find the description eyeD3 uses.
-        cmt = pack(cmt.encode("latin_1"), 30)
+        cmt = pack(encode(cmt), 30)
 
         if version != ID3_V1_0:
             track = self.track_num[0]
@@ -1219,10 +1224,11 @@ class Tag(core.Tag):
     def frameiter(self, fids=None):
         '''A iterator for tag frames. If ``fids`` is passed it must be a list
         of frame IDs to filter and return.'''
+        fids = fids or []
         fids = [(b(f, ascii_encode)
             if isinstance(f, UnicodeType) else f) for f in fids]
         for f in self.frame_set.getAllFrames():
-            if f.id in fids:
+            if not fids or f.id in fids:
                 yield f
 
 
@@ -1311,6 +1317,7 @@ class DltAccessor(AccessorBase):
 
     @requireUnicode(1, 2)
     def set(self, text, description=u"", lang=DEFAULT_LANG):
+        lang = lang or DEFAULT_LANG
         for f in self._fs[self._fid] or []:
             if f.description == description and f.lang == lang:
                 # Exists, update text
@@ -1324,11 +1331,13 @@ class DltAccessor(AccessorBase):
 
     @requireUnicode(1)
     def remove(self, description, lang=DEFAULT_LANG):
-        return super(DltAccessor, self).remove(description, lang=lang)
+        return super(DltAccessor, self).remove(description,
+                                               lang=lang or DEFAULT_LANG)
 
     @requireUnicode(1)
     def get(self, description, lang=DEFAULT_LANG):
-        return super(DltAccessor, self).get(description, lang=lang)
+        return super(DltAccessor, self).get(description,
+                                            lang=lang or DEFAULT_LANG)
 
 
 class CommentsAccessor(DltAccessor):
@@ -1743,20 +1752,26 @@ class TagTemplate(string.Template):
 
         return dstr
 
-    def _track(self, tag, param, zeropad):
-        tn, tt = (unicode(n) if n else None for n in tag.track_num)
+    def _nums(self, num_tuple, param, zeropad):
+        nn, nt = ((unicode(n) if n else None) for n in num_tuple)
         if zeropad:
-            if tt:
-                tt = tt.rjust(2, "0")
-            tn = tn.rjust(len(tt) if tt else 2, "0")
+            if nt:
+                nt = nt.rjust(2, "0")
+            nn = nn.rjust(len(nt) if nt else 2, "0")
 
         if param.endswith(":num"):
-            return tn
+            return nn
         elif param.endswith(":total"):
-            return tt
+            return nt
         else:
             raise ValueError("Unknown template param: %s" % param)
 
+    def _track(self, tag, param, zeropad):
+        return self._nums(tag.track_num, param, zeropad)
+
+    def _disc(self, tag, param, zeropad):
+        return self._nums(tag.disc_num, param, zeropad)
+
     def _file(self, tag, param):
         assert(param.startswith("file"))
 
@@ -1788,4 +1803,6 @@ class TagTemplate(string.Template):
                                                                    else None,
                 "file": (self._file,) if tag else None,
                 "file:ext": (self._file,) if tag else None,
+                "disc:num": (self._disc, zeropad) if tag else None,
+                "disc:total": (self._disc, zeropad) if tag else None,
                }
